@@ -22,7 +22,6 @@ import sys
 import tempfile
 
 import ansible.constants
-from ansible.parsing.yaml.objects import AnsibleVaultEncryptedUnicode
 
 from kayobe import exception
 from kayobe import utils
@@ -125,6 +124,11 @@ def _validate_args(parsed_args, playbooks):
                   parsed_args.config_path, result["message"])
         sys.exit(1)
 
+    if parsed_args.environment and parsed_args.environment == "kayobe":
+        LOG.error("The environment name 'kayobe' is reserved for internal "
+                  "use.")
+        sys.exit(1)
+
     env_path = _get_kayobe_environment_path(parsed_args)
     if env_path:
         result = utils.is_readable_dir(env_path)
@@ -298,18 +302,6 @@ def run_playbook(parsed_args, playbook, *args, **kwargs):
     return run_playbooks(parsed_args, [playbook], *args, **kwargs)
 
 
-def _sanitise_hostvar(var):
-    """Sanitise a host variable."""
-    if isinstance(var, AnsibleVaultEncryptedUnicode):
-        return "******"
-    # Recursively sanitise dicts and lists.
-    if isinstance(var, dict):
-        return {k: _sanitise_hostvar(v) for k, v in var.items()}
-    if isinstance(var, list):
-        return [_sanitise_hostvar(v) for v in var]
-    return var
-
-
 def config_dump(parsed_args, host=None, hosts=None, var_name=None,
                 facts=None, extra_vars=None, tags=None, verbose_level=None):
     dump_dir = tempfile.mkdtemp()
@@ -335,8 +327,7 @@ def config_dump(parsed_args, host=None, hosts=None, var_name=None,
             LOG.debug("Found dump file %s", path)
             inventory_hostname, ext = os.path.splitext(path)
             if ext == ".yml":
-                dump_file = os.path.join(dump_dir, path)
-                hvars = utils.read_config_dump_yaml_file(dump_file)
+                hvars = utils.read_yaml_file(os.path.join(dump_dir, path))
                 if host:
                     return hvars
                 else:
@@ -344,7 +335,7 @@ def config_dump(parsed_args, host=None, hosts=None, var_name=None,
             else:
                 LOG.warning("Unexpected extension on config dump file %s",
                             path)
-        return {k: _sanitise_hostvar(v) for k, v in hostvars.items()}
+        return hostvars
     finally:
         shutil.rmtree(dump_dir)
 
