@@ -52,10 +52,13 @@ def add_args(parser):
                         help="specify inventory host path "
                              "(default=$%s/inventory or %s/inventory) for "
                              "Kolla Ansible" %
-                             (CONFIG_PATH_ENV, DEFAULT_CONFIG_PATH))
+                             (CONFIG_PATH_ENV, DEFAULT_CONFIG_PATH),
+                        action='append')
     parser.add_argument("-kl", "--kolla-limit", metavar="SUBSET",
                         help="further limit selected hosts to an additional "
                              "pattern")
+    parser.add_argument("-kp", "--kolla-playbook", metavar="PLAYBOOK",
+                        help="path to Ansible playbook file")
     parser.add_argument("--kolla-skip-tags", metavar="TAGS",
                         help="only run plays and tasks whose tags do not "
                              "match these values in Kolla Ansible")
@@ -68,35 +71,53 @@ def add_args(parser):
                              (VENV_PATH_ENV, DEFAULT_VENV_PATH))
 
 
-def _get_inventory_path(parsed_args, inventory_filename):
+def _get_inventory_paths(parsed_args, inventory_filename):
     """Return the path to the Kolla inventory."""
     if parsed_args.kolla_inventory:
         return parsed_args.kolla_inventory
     else:
-        return os.path.join(parsed_args.kolla_config_path, "inventory",
-                            inventory_filename)
+        paths = [os.path.join(parsed_args.kolla_config_path, "inventory",
+                              inventory_filename)]
+
+        def append_path(directory):
+            candidate_path = os.path.join(
+                parsed_args.kolla_config_path, "extra-inventories",
+                directory)
+            if utils.is_readable_dir(candidate_path)["result"]:
+                paths.append(candidate_path)
+
+        # Inventory in the base layer is placed in the "kayobe"
+        # directory. This means that you can't have an environment
+        # called kayobe as it would conflict.
+        append_path("kayobe")
+
+        if parsed_args.environment:
+            append_path(parsed_args.environment)
+
+        return paths
 
 
 def _validate_args(parsed_args, inventory_filename):
     """Validate Kayobe Ansible arguments."""
-    vault.validate_args(parsed_args)
+    vault.enforce_single_password_source(parsed_args)
     result = utils.is_readable_dir(parsed_args.kolla_config_path)
     if not result["result"]:
         LOG.error("Kolla configuration path %s is invalid: %s",
                   parsed_args.kolla_config_path, result["message"])
         sys.exit(1)
 
-    inventory = _get_inventory_path(parsed_args, inventory_filename)
-    result = utils.is_readable_dir(inventory)
-    if not result["result"]:
-        # NOTE(mgoddard): Previously the inventory was a file, now it is a
-        # directory to allow us to support inventory host_vars. Support both
-        # formats for now.
-        result_f = utils.is_readable_file(inventory)
-        if not result_f["result"]:
-            LOG.error("Kolla inventory %s is invalid: %s",
-                      inventory, result["message"])
-            sys.exit(1)
+    inventories = _get_inventory_paths(parsed_args, inventory_filename)
+    for inventory in inventories:
+        result = utils.is_readable_dir(inventory)
+        if not result["result"]:
+            # NOTE(mgoddard): Previously the inventory was a file, now it is a
+            # directory to allow us to support inventory host_vars. Support
+            # both formats for now.
+            result_f = utils.is_readable_file(inventory)
+            if not result_f["result"]:
+                LOG.error("Kolla inventory %s is invalid: %s",
+                          inventory, result["message"])
+                sys.exit(1)
 
     result = utils.is_readable_dir(parsed_args.kolla_venv)
     if not result["result"]:
@@ -104,6 +125,13 @@ def _validate_args(parsed_args, inventory_filename):
                   parsed_args.kolla_venv, result["message"])
         sys.exit(1)
 
+    if parsed_args.kolla_playbook:
+        result = utils.is_readable_file(parsed_args.kolla_playbook)
+        if not result["result"]:
+            LOG.error("Kolla Ansible playbook %s is invalid: %s",
+                      parsed_args.kolla_playbook, result["message"])
+            sys.exit(1)
+
 
 def build_args(parsed_args, command, inventory_filename, extra_vars=None,
                tags=None, verbose_level=None, extra_args=None, limit=None):
@@ -113,9 +141,12 @@ def build_args(parsed_args, command, inventory_filename, extra_vars=None,
     cmd += ["kolla-ansible", command]
     if verbose_level:
         cmd += ["-" + "v" * verbose_level]
+    if parsed_args.kolla_playbook:
+        cmd += ["--playbook", parsed_args.kolla_playbook]
     cmd += vault.build_args(parsed_args, "--key")
-    inventory = _get_inventory_path(parsed_args, inventory_filename)
-    cmd += ["--inventory", inventory]
+    inventories = _get_inventory_paths(parsed_args, inventory_filename)
+    for inventory in inventories:
+        cmd += ["--inventory", inventory]
     if parsed_args.kolla_config_path != DEFAULT_CONFIG_PATH:
         cmd += ["--configdir", parsed_args.kolla_config_path]
         cmd += ["--passwords",
@@ -157,6 +188,14 @@ def _get_environment(parsed_args):
         ansible_cfg_path = os.path.join(parsed_args.config_path, "ansible.cfg")
         if utils.is_readable_file(ansible_cfg_path)["result"]:
             env.setdefault("ANSIBLE_CONFIG", ansible_cfg_path)
+    # kolla-ansible allows passing additional arguments to ansible-playbook via
+    # EXTRA_OPTS.
+    if parsed_args.check or parsed_args.diff:
+        extra_opts = env.setdefault("EXTRA_OPTS", "")
+        if parsed_args.check and "--check" not in extra_opts:
+            env["EXTRA_OPTS"] += " --check"
+        if parsed_args.diff and "--diff" not in extra_opts:
+            env["EXTRA_OPTS"] += " --diff"
     return env
 
 
