@@ -14,6 +14,7 @@
 
 import argparse
 import errno
+import logging
 import os
 import os.path
 import shutil
@@ -92,6 +93,53 @@ class TestCase(unittest.TestCase):
                                          quiet=False, env=expected_env)
         mock_vars.assert_called_once_with(["/etc/kayobe"])
 
+    @mock.patch.object(ansible, "_get_vars_files")
+    @mock.patch.object(utils, "is_readable_dir")
+    @mock.patch.object(utils, "is_readable_file")
+    @mock.patch.object(utils, "run_command")
+    def test_reserved_environment(
+            self, mock_run, mock_readable,
+            mock_readable_file, mock_vars):
+        mock_readable_file.return_value = {"result": True}
+        mock_readable.return_value = {"result": True}
+        mock_vars.return_value = ["/path/to/config/vars-file1.yml",
+                                  "/path/to/config/vars-file2.yaml"]
+        parser = argparse.ArgumentParser()
+        ansible.add_args(parser)
+        vault.add_args(parser)
+        args = [
+            "--environment", "kayobe",
+        ]
+        parsed_args = parser.parse_args(args)
+        with self.assertLogs(level=logging.ERROR) as ctx:
+            self.assertRaises(
+                SystemExit, ansible.run_playbooks, parsed_args,
+                ["playbook1.yml"]
+            )
+            exp = "The environment name 'kayobe' is reserved for internal use."
+            log_found = any(exp in t for t in ctx.output)
+            assert(log_found)
+
+    @mock.patch.object(ansible, "_get_vars_files")
+    @mock.patch.object(utils, "is_readable_dir")
+    @mock.patch.object(utils, "is_readable_file")
+    @mock.patch.object(utils, "run_command")
+    def test_reserved_environment_negative(
+            self, mock_run, mock_readable,
+            mock_readable_file, mock_vars):
+        mock_readable_file.return_value = {"result": True}
+        mock_readable.return_value = {"result": True}
+        mock_vars.return_value = ["/path/to/config/vars-file1.yml",
+                                  "/path/to/config/vars-file2.yaml"]
+        parser = argparse.ArgumentParser()
+        ansible.add_args(parser)
+        vault.add_args(parser)
+        args = [
+            "--environment", "kayobe2",
+        ]
+        parsed_args = parser.parse_args(args)
+        ansible.run_playbooks(parsed_args, ["playbook1.yml", "playbook2.yml"])
+
     @mock.patch.object(utils, "run_command")
     @mock.patch.object(ansible, "_get_vars_files")
     @mock.patch.object(ansible, "_validate_args")
@@ -535,7 +583,7 @@ class TestCase(unittest.TestCase):
                           ansible.run_playbooks, parsed_args, ["command"])
 
     @mock.patch.object(shutil, 'rmtree')
-    @mock.patch.object(utils, 'read_config_dump_yaml_file')
+    @mock.patch.object(utils, 'read_yaml_file')
     @mock.patch.object(os, 'listdir')
     @mock.patch.object(ansible, 'run_playbook')
     @mock.patch.object(tempfile, 'mkdtemp')
@@ -573,70 +621,6 @@ class TestCase(unittest.TestCase):
             mock.call(os.path.join(dump_dir, "host2.yml")),
         ])
 
-    @mock.patch.object(shutil, 'rmtree')
-    @mock.patch.object(utils, 'read_file')
-    @mock.patch.object(os, 'listdir')
-    @mock.patch.object(ansible, 'run_playbook')
-    @mock.patch.object(tempfile, 'mkdtemp')
-    def test_config_dump_vaulted(self, mock_mkdtemp, mock_run, mock_listdir,
-                                 mock_read, mock_rmtree):
-        parser = argparse.ArgumentParser()
-        parsed_args = parser.parse_args([])
-        dump_dir = "/path/to/dump"
-        mock_mkdtemp.return_value = dump_dir
-        mock_listdir.return_value = ["host1.yml", "host2.yml"]
-        config = """---
-key1: !vault |
-  $ANSIBLE_VAULT;1.1;AES256
-  633230623736383232323862393364323037343430393530316636363961626361393133646437
-  643438663261356433656365646138666133383032376532310a63323432306431303437623637
-  346236316161343635636230613838316566383933313338636237616338326439616536316639
-  6334343462333062363334300a3930313762313463613537626531313230303731343365643766
-  666436333037
-key2: value2
-key3:
-  - !vault |
-    $ANSIBLE_VAULT;1.1;AES256
-    633230623736383232323862393364323037343430393530316636363961626361393133646437
-    643438663261356433656365646138666133383032376532310a63323432306431303437623637
-    346236316161343635636230613838316566383933313338636237616338326439616536316639
-    6334343462333062363334300a3930313762313463613537626531313230303731343365643766
-    666436333037
-"""
-        config_nested = """---
-key1:
-  key2: !vault |
-    $ANSIBLE_VAULT;1.1;AES256
-    633230623736383232323862393364323037343430393530316636363961626361393133646437
-    643438663261356433656365646138666133383032376532310a63323432306431303437623637
-    346236316161343635636230613838316566383933313338636237616338326439616536316639
-    6334343462333062363334300a3930313762313463613537626531313230303731343365643766
-    666436333037
-"""
-        mock_read.side_effect = [config, config_nested]
-        result = ansible.config_dump(parsed_args)
-        expected_result = {
-            "host1": {"key1": "******", "key2": "value2", "key3": ["******"]},
-            "host2": {"key1": {"key2": "******"}},
-        }
-        self.assertEqual(result, expected_result)
-        dump_config_path = utils.get_data_files_path(
-            "ansible", "dump-config.yml")
-        mock_run.assert_called_once_with(parsed_args,
-                                         dump_config_path,
-                                         extra_vars={
-                                             "dump_path": dump_dir,
-                                         },
-                                         check_output=True, tags=None,
-                                         verbose_level=None, check=False,
-                                         list_tasks=False, diff=False)
-        mock_rmtree.assert_called_once_with(dump_dir)
-        mock_listdir.assert_any_call(dump_dir)
-        mock_read.assert_has_calls([
-            mock.call(os.path.join(dump_dir, "host1.yml")),
-            mock.call(os.path.join(dump_dir, "host2.yml")),
-        ])
-
     @mock.patch.object(utils, 'galaxy_role_install', autospec=True)
     @mock.patch.object(utils, 'is_readable_file', autospec=True)
     @mock.patch.object(os, 'makedirs', autospec=True)
